/* ----------------------------------------------------------------------------
 *         ATMEL Microcontroller Software Support
 * ----------------------------------------------------------------------------
 * Copyright (c) 2014, Atmel Corporation
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer below.
 *
 * Atmel's name may not be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * DISCLAIMER: THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ----------------------------------------------------------------------------
 */


#ifndef PLAYCONTROLS_H
#define PLAYCONTROLS_H

#include <QWidget>

// Button images
#define PLAY_IMG    ":/playcontrols/images/Play.png"
#define PAUSE_IMG   ":/playcontrols/images/Pause.png"
#define MUTE_IMG    ":/playcontrols/images/speaker.png"
#define UNMUTE_IMG  ":/playcontrols/images/speaker_mute.png"

/**
 * @file playcontrols.h
 * @brief Video player play controls implementation
 */

namespace Ui {
class PlayControls;
}

class PlayControls : public QWidget
{
    Q_OBJECT

public:
    explicit PlayControls(QWidget *parent = 0);
    ~PlayControls();

    /**
     * @brief setCPUusage Sets the value in the CPU usage progress bar
     * @param usage Percentage of CPU utilization
     */
    void setCPUusage(int usage);

    /**
     * @brief allowSeek Allow the controls to emit a positionChanged signal when the slider is moved
     * @param allow true = allow seeking, fasle = don´t allow seeking (default true)
     */
    void allowSeek(bool allow);

    /**
     * @brief enableVolumeControl Enable/Disable the volume controls
     * @param enable True = volume controls enabled, false = volume controls disabled (default state enabled)
     */
    void enableVolumeControl(bool enable);

    /**
     * @brief getCurrentVolume
     * @return the current volume configured on the volume slider
     */
    int getCurrentVolume();

    /**
     * @brief getCurrentMute
     * @return the current mute state
     */
    bool getCurrentMute();

signals:
    void play();
    void pause();
    void setMute(bool mute);
    void setVolume(int volume);
    void positionChanged(int position);
    void setFullScreen();
    void showOptions();

private slots:
    void on_PlayPause_clicked();
    void on_muteButton_clicked();
    /**
     * @brief durationChanged UPdates the Media progress status bar maximum value and media duration label
     * @param duration Media duration
     */
    void durationChanged(qint64 duration);
    /**
     * @brief positionChanged Updates the Media progress status bar current position and Media position label
     * @param position Current meda position (position < = duration)
     */
    void positionChanged(qint64 position);

    void on_fullScreenButtonn_clicked();

public slots:
    /**
      * @brief set the controls to the current play state
      *
      * @param state true = onPlay, false = onPause
      */
    void setPlayState(bool state);

private:
    Ui::PlayControls *ui;

    // internal funcions
    void updatePositionLabel(int position);
    QString secondsToString(int seconds);
    void setPlayIcon(bool state);


    // Internal variables
    bool _onPlay;               // Video is playing
    bool _onMute;               // Video is paused
    int _totalDuration;         // Video total duration
    QString _duration;          // Video total duration (hh:mm:ss formated)
    int _currentPosition;       // Current position of the stream
    bool _allowSeek;            // Allow seek
};

#endif // PLAYCONTROLS_H
