/* ----------------------------------------------------------------------------
 *         ATMEL Microcontroller Software Support
 * ----------------------------------------------------------------------------
 * Copyright (c) 2014, Atmel Corporation
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer below.
 *
 * Atmel's name may not be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * DISCLAIMER: THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ----------------------------------------------------------------------------
 */


#ifndef PLAYER_H
#define PLAYER_H

#include <QMainWindow>
#include <QToolBar>
#include <QTimer>
#include <QFileDialog>
#include <QLabel>
#include <QKeyEvent>

#include "tools.h"
#include "playcontrols.h"
#include "videoplayer.h"


/**
 * @file player.h
 * @brief Video player main class implementation
 */

/**
  * @mainpage Video Player Demo
 *  @details
 *  @version   1.0
 *  @date      August 2014
 *
 *
 * \section contents Contents
 * - \ref introsec
 *
 * \section introsec Introduction
 *
 * Library for the managment of common tasks
 *
 */

namespace Ui {
class Player;
}

class Player : public QMainWindow
{
    Q_OBJECT

public:
    explicit Player(QWidget *parent = 0);
    ~Player();

private:
    Ui::Player *ui;

    Tools *_tools;

    QToolBar        *_toolBar;           // To hold the play controls
    QLabel          *_fpsL;          // To display video statistics
    PlayControls    *_controls;          // Play controls
    VideoPlayer     *_videoplayer;       // gstreamer implementation
    QTimer          *_cpuTimer;          // To update CPU usage
    QTimer *_hideControlsTimer;          // Hide controls after some time with no activity
    int            _hideTimeout;         // Time to hide controls (in seconds)
    QFileDialog     *_openFileDialog;    // select media file


    void setUpPlayControls();
    void setUpFpsLabel();
    void mousePressEvent (QMouseEvent *);
    void mouseMoveEvent(QMouseEvent *);


private slots:
    void updateCPUusage();
    void fpsChanged(QString perf);
    void onControlsTimeout();
    void onSetFullScreen();
    void onOpenFile();

protected:
    void keyPressEvent( QKeyEvent * );

};

#endif // PLAYER_H
