/* ----------------------------------------------------------------------------
 *         ATMEL Microcontroller Software Support
 * ----------------------------------------------------------------------------
 * Copyright (c) 2014, Atmel Corporation
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer below.
 *
 * Atmel's name may not be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * DISCLAIMER: THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ----------------------------------------------------------------------------
 */


#ifndef TOOLS_H
#define TOOLS_H

#include <fstream>
#include <fcntl.h>
#include <sys/ioctl.h>
#include <cstdlib>
#include <cstring>
#include <QWidget>
#include <QFile>
#include <QTextStream>

#include <string.h> /* for strncpy */
#include <iostream>
#include <string>
#include <sstream>

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <net/if.h>
#include <arpa/inet.h>

#include <unistd.h>
#include <linux/fb.h>

/**
 * @file tools.h
 * @brief Colection of functions to perform common tasks
 */

/**
 *  @brief
 *  Tools
 * */
class Tools
{
public:
    Tools();

    virtual ~Tools();

    // Stores CPU usage
    float  cpu_usage[4];

    /**
      * Enables the selected layer with the given dimensions
      *
      * @param w Layer width
      * @param h Layer height
      * @param layer Layer number (0 = base, 1 = ovr1, 2 = ovr2)
      *
      * @return True if succeded
      **/
    bool enableLayer(int w, int h, int layer);


    /**
        * Set the nonstd according to the givin dimensions
        *
        * @param w Layer width
        * @param h Layer height
        * @param layer Layer number (0 = base, 1 = ovr1, 2 = ovr2)
        *
        * @return True if succeded
        **/
    bool setStatdard(int w, int h, int layer);

    /**
      * Looks into filepath for key and returns into value the characters between {}.\n
      * sintax: key={value}\n
      *
      *@param filepath complete file path
      *@param key string to be found
      *@param value returned text (if found)
      *@return true if success
      */
    bool getKey(const char* filepath, std::string key, QString &value);

    /**
      * Convert an int value to a std::string
      *
      *@param value int value
      *@return std_string
      */
    std::string to_string(int value);

    /**
      * Print a string to std output
      *
      * @param message Message to be printed
      *
      **/
    void printToStdOUT(QString message);


    /**
      * Updates the CPU Usage
      * The value is stored in the public cpu_usage array
      **/
    void updateCpuUsage();

private:
    QString res_spec;

    // For CPU usage
    float total_cpu_last_time[4];
    float work_cpu_last_time[4];
};

#endif // TOOLS_H
