/* ----------------------------------------------------------------------------
 *         ATMEL Microcontroller Software Support
 * ----------------------------------------------------------------------------
 * Copyright (c) 2014, Atmel Corporation
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer below.
 *
 * Atmel's name may not be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * DISCLAIMER: THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ----------------------------------------------------------------------------
 */


#ifndef VIDEOPLAYER_H
#define VIDEOPLAYER_H

#include <QObject>
#include <gst/gst.h>
#include <stdio.h>


/**
 * @file videoplayer.h
 * @brief Player  gstreamer class
 */


class VideoPlayer : public QObject
{
    Q_OBJECT
public:
    VideoPlayer();
    ~VideoPlayer();


    /**
     * @brief Sets the media file URI to the current pipeline
     * @param uri file URI
     * @return true if success
     */
    bool setMedia(QString uri);

signals:
    void durationChanged(qint64 duration);      // Media Duration changed
    void positionChanged(qint64 position);      // Media position changed
    void fpsChanged(QString fps);      // Media position changed
    void playState(bool state);                 // pipeline play state (true = onPlay, false = onPause)

public slots:
    /**
     * @brief play Send pipeline to play state
     * @return  true if success
     */
    bool play();
    /**
     * @brief pause Send Pipeline to pause state
     * @return true is success
     */
    bool pause();
    /**
     * @brief null Send pipeline to null state
     * @return true if success
     */
    bool null();

    /**
     * @brief Adjusts the volume of the audio in the video being played
     * @param volume desired volume in the range of 0 (no sound) to 100 (normal sound)
     * @return true if success
     */
    bool setVolume(int volume);

    /**
     * @brief Mutes the audio of the video being played
     * @param mute true if the audio is to be muted
     * @return true if success
     */
    bool setMute(bool mute);

private:
    GstElement *_videoPipeline;      // Video Pipeline
    GstElement *_src;                // Source element
    GstElement *_volume;             // Volume controller

    bool setState(GstState state);
    bool createPipeline();
    void destroyPipeline();

};

#endif // VIDEOPLAYER_H
